@@ -27,13 +27,14 @@ define('OX_COMPONENT_SUFFIX', '.class.php');
  * @static
  * @package    OpenXPlugin
  */
-class OX_Component
+abstract class OX_Component
 {
     public $extension;
     public $group;
     public $component;
     public $enabled;
 
+    /** @var OX_Translation */
     public $oTrans;
 
     /**
@@ -70,14 +71,16 @@ class OX_Component
         return $obj;
     }
 
+    /**
+     * @return OX_Component|false
+     */
     public static function factoryByComponentIdentifier($componentIdentifier)
     {
         $aParts = self::parseComponentIdentifier($componentIdentifier);
         if (!$aParts) {
             return false;
         }
-        $returned = call_user_func_array(['OX_Component', 'factory'], $aParts);
-        return $returned;
+        return OX_Component::factory(...$aParts);
     }
 
     public static function _isGroupInstalled($group)
@@ -87,7 +90,7 @@ class OX_Component
 
     public static function _isGroupEnabled($group)
     {
-        return (self::_isGroupInstalled($group) && $GLOBALS['_MAX']['CONF']['pluginGroupComponents'][$group] ? true : false);
+        return (self::_isGroupInstalled($group) && $GLOBALS['_MAX']['CONF']['pluginGroupComponents'][$group]);
     }
 
     /**
@@ -240,7 +243,7 @@ class OX_Component
         if (is_readable($directory)) {
             if ($aFiles = scandir($directory)) {
                 foreach ($aFiles as $i => $name) {
-                    if (substr($name, 0, 1) == '.') {
+                    if (str_starts_with($name, '.')) {
                         continue;
                     }
                     if (is_dir($directory . $name)) {
@@ -279,7 +282,7 @@ class OX_Component
                 $aMatches = array_merge($aMatches, preg_grep($fileMask, $aFiles));
                 if ($recursive) {
                     foreach ($aFiles as $i => $name) {
-                        if (substr($name, 0, 1) == '.') {
+                        if (str_starts_with($name, '.')) {
                             continue;
                         }
                         if (is_dir($directory . DIRECTORY_SEPARATOR . $name)) {
@@ -381,10 +384,7 @@ class OX_Component
     public static function getListOfRegisteredComponentsForHook($hook)
     {
         $aHooks = self::getComponentsHookCache();
-        if (isset($aHooks[$hook])) {
-            return $aHooks[$hook];
-        }
-        return [];
+        return $aHooks[$hook] ?? [];
     }
 
     public static function getComponentsHookCache()
